import { Construct } from 'constructs';
import { Chart } from './chart';
/**
 * @stability stable
 */
export interface AppProps {
    /**
     * The directory to output Kubernetes manifests.
     *
     * @default - CDK8S_OUTDIR if defined, otherwise "dist"
     * @stability stable
     */
    readonly outdir?: string;
}
/**
 * Represents a cdk8s application.
 *
 * @stability stable
 */
export declare class App extends Construct {
    /**
     * Synthesize a single chart.
     *
     * Each element returned in the resulting array represents a different ApiObject
     * in the scope of the chart.
     *
     * Note that the returned array order is important. It is determined by the various dependencies between
     * the constructs in the chart, where the first element is the one without dependencies, and so on...
     *
     * @returns An array of JSON objects.
     * @param chart the chart to synthesize.
     * @internal
     */
    static _synthChart(chart: Chart): any[];
    private static of;
    /**
     * The output directory into which manifests will be synthesized.
     *
     * @stability stable
     */
    readonly outdir: string;
    /**
     * Defines an app.
     *
     * @param props configuration options.
     * @stability stable
     */
    constructor(props?: AppProps);
    /**
     * Synthesizes all manifests to the output directory.
     *
     * @stability stable
     */
    synth(): void;
}
